@@ -1,4 +1,6 @@
-__version__ = "1.3.1"
+__version__ = "1.3.4"
+
+# this __all__ is used for documentation generation, not for imports
 __all__ = [
     "morebuiltins.utils",
     "morebuiltins.date",
@@ -18,4 +20,5 @@ __all__ = [
     "morebuiltins.cmd.systemd.timer",
     "morebuiltins.sqlite",
     "morebuiltins.shared_memory",
+    "morebuiltins.logs",
 ]
