@@ -4,22 +4,15 @@ import importlib
 import importlib.util
 import inspect
 import json
-import logging
 import os
-import re
 import sys
 import time
 from collections import deque
-from concurrent.futures import ThreadPoolExecutor
+from concurrent.futures import Future, ThreadPoolExecutor
 from contextvars import copy_context
 from functools import partial, wraps
-from gzip import GzipFile
 from itertools import chain
-from logging.handlers import QueueHandler, QueueListener, TimedRotatingFileHandler
-from multiprocessing import Queue as ProcessQueue
-from pathlib import Path
-from queue import Queue
-from threading import Lock, RLock, Semaphore, Thread
+from threading import Lock, Semaphore
 from typing import (
     Any,
     Callable,
@@ -41,11 +34,9 @@ __all__ = [
     "NamedLock",
     "FuncSchema",
     "InlinePB",
-    "SizedTimedRotatingFileHandler",
     "get_type_default",
     "func_cmd",
     "file_import",
-    "RotatingFileWriter",
     "get_function",
     "to_thread",
     "check_recursion",
@@ -192,9 +183,9 @@ def threads(n: Optional[int] = None, executor_class=None, **kws):
     pool = (executor_class or ThreadPoolExecutor)(max_workers=n, **kws)
     tasks: WeakSet = WeakSet()
 
-    def decorator(func):
+    def decorator(func) -> Callable[..., Future]:
         @wraps(func)
-        def wrapped(*args, **kwargs):
+        def wrapped(*args, **kwargs) -> Future:
             future = pool.submit(func, *args, **kwargs)
             future.add_done_callback(lambda task: tasks.discard(task))
             tasks.add(future)
@@ -226,9 +217,6 @@ def bg_task(coro: Coroutine) -> asyncio.Task:
     return task
 
 
-LockType = Union[Lock, Semaphore, asyncio.Lock, asyncio.Semaphore]
-
-
 class NamedLock:
     """Reusable named locks, support for timeouts, support for multiple concurrent locks.
 
@@ -296,10 +284,12 @@ class NamedLock:
             test_async()
     """
 
-    _SYNC_CACHE: Dict[str, LockType] = {}
-    _ASYNC_CACHE: Dict[str, LockType] = {}
+    _SYNC_CACHE: Dict[str, Union[Lock, Semaphore]] = {}
+    _ASYNC_CACHE: Dict[str, Union[asyncio.Lock, asyncio.Semaphore]] = {}
 
-    def __init__(self, name: str, default_factory: Callable, timeout=None):
+    def __init__(
+        self, name: str, default_factory: Callable, timeout: Optional[float] = None
+    ):
         self.name = name
         self.default_factory = default_factory
         self.timeout = timeout
@@ -309,10 +299,12 @@ class NamedLock:
     def clear_unlocked(cls):
         for cache in [cls._SYNC_CACHE, cls._ASYNC_CACHE]:
             for name, lock in list(cache.items()):
-                if hasattr(lock, "locked") and not lock.locked():
+                locked_method = getattr(lock, "locked", None)
+                if locked_method and not locked_method():
                     cache.pop(name, None)
                 elif isinstance(lock, Semaphore) and (
-                    lock._value == 0 or not lock._cond._lock.locked()
+                    lock._value == 0
+                    or (hasattr(lock, "_cond") and not lock._cond._lock.locked())
                 ):
                     cache.pop(name, None)
 
@@ -556,193 +548,6 @@ class InlinePB(object):
         )
 
 
-class SizedTimedRotatingFileHandler(TimedRotatingFileHandler):
-    """TimedRotatingFileHandler with maxSize, to avoid files that are too large.
-
-
-    Demo::
-
-        import logging
-        import time
-        from morebuiltins.funcs import SizedTimedRotatingFileHandler
-
-        logger = logging.getLogger("test1")
-        h = SizedTimedRotatingFileHandler(
-            "logs/test1.log", "d", 1, 3, maxBytes=1, ensure_dir=True
-        )
-        h.setFormatter(logging.Formatter("%(asctime)s %(levelname)s %(message)s"))
-        logger.addHandler(h)
-
-        for i in range(5):
-            logger.warning(str(i) * 102400)
-            time.sleep(1)
-        # 102434 test1.log
-        # 102434 test1.log.20241113_231000
-        # 102434 test1.log.20241113_231001
-        # 102434 test1.log.20241113_231002
-        logger = logging.getLogger("test2")
-        h = SizedTimedRotatingFileHandler(
-            "logs/test2.log", "d", 1, 3, maxBytes=1, compress=True
-        )
-        h.setFormatter(logging.Formatter("%(asctime)s %(levelname)s %(message)s"))
-        logger.addHandler(h)
-
-        for i in range(5):
-            logger.warning(str(i) * 102400)
-            time.sleep(1)
-        # 102434 test2.log
-        #    186 test2.log.20241113_231005.gz
-        #    186 test2.log.20241113_231006.gz
-        #    186 test2.log.20241113_231007.gz
-
-    """
-
-    do_compress_delay = 0.1
-
-    def __init__(
-        self,
-        filename,
-        when="h",
-        interval=1,
-        backupCount=0,
-        maxBytes=0,
-        encoding=None,
-        delay=False,
-        utc=False,
-        compress=False,
-        ensure_dir=True,
-    ):
-        """
-        Initialize the timed backup file handler.
-
-        :param filename: The name of the log file.
-        :param when: The time unit for timed backups, can be "h" (hours) or "d" (days)
-        :param interval: The interval for timed backups, with the unit determined by the 'when' parameter
-        :param backupCount: The maximum number of backup files to keep
-        :param maxBytes: The file size limit before triggering a backup (0 means no limit)
-        :param encoding: The encoding of the file
-        :param delay: Whether to delay opening the file until the first write
-        :param utc: Whether to use UTC time for naming backups
-        """
-        self.log_path = Path(filename)
-        if ensure_dir:
-            self.log_path.parent.mkdir(parents=True, exist_ok=True)
-        super().__init__(filename, when, interval, backupCount, encoding, delay, utc)
-        self.maxBytes = maxBytes
-        self.suffix = "%Y%m%d_%H%M%S"
-        self.compress = compress
-        self.need_compress = False
-        self.comress_chunk_size = 64 * 1024
-        self.extMatch = re.compile(r"^\d{4}\d{2}\d{2}_\d{2}\d{2}\d{2}$", re.ASCII)
-
-    def do_compress_async(self):
-        if getattr(self, "_background_compress", None):
-            return
-        self._compressing = Thread(
-            target=self.do_compress, daemon=False, name="do_compress_async"
-        )
-        self._compressing.start()
-
-    def gzip_log(self, path: Path):
-        try:
-            temp_path = path.with_suffix(".tmp.gz")
-            with open(path, "rb") as f:
-                with GzipFile(temp_path, "wb") as gz:
-                    size = 0
-                    lines = []
-                    for line in f:
-                        size += len(line)
-                        lines.append(line)
-                        if size > self.comress_chunk_size:
-                            gz.writelines(lines)
-                            size = 0
-                            lines = []
-                    if lines:
-                        gz.writelines(lines)
-            if path.is_file():
-                try:
-                    path.unlink()
-                    temp_path.rename(path.with_suffix(f"{path.suffix}.gz"))
-                except OSError:
-                    pass
-        except OSError:
-            pass
-        finally:
-            try:
-                temp_path.unlink(missing_ok=True)
-            except OSError:
-                pass
-
-    def do_compress(self):
-        try:
-            while self.need_compress:
-                self.need_compress = False
-                time.sleep(self.do_compress_delay)
-                now_suffix = f".{time.strftime(self.suffix)}"
-                path_list = []
-                for path in self.log_path.parent.glob(f"{self.log_path.name}.*"):
-                    if path.suffix == now_suffix:
-                        self.need_compress = True
-                        continue
-                    for time_suffix in path.name.split(".")[-2:]:
-                        if self.extMatch.match(time_suffix):
-                            path_list.append((time_suffix, path))
-                path_list.sort()
-                target_index = len(path_list) - self.backupCount
-                for index, (_, path) in enumerate(path_list):
-                    if index < target_index:
-                        try:
-                            path.unlink(missing_ok=True)
-                        except OSError:
-                            pass
-                        continue
-                    elif path.suffix == ".gz":
-                        continue
-                    else:
-                        self.gzip_log(path)
-        finally:
-            self._compressing = None
-
-    def shouldRollover(self, record):
-        """
-        Determine if rollover should occur.
-        Basically, see if the supplied record would cause the file to exceed
-        the size limit we have.
-        """
-        if super().shouldRollover(record):
-            return True
-
-        if self.maxBytes > 0:
-            if self.stream.tell() >= self.maxBytes:
-                return True
-        return False
-
-    def doRollover(self):
-        """
-        Do a rollover, as described by the base class documentation.
-        However, also check for the maxBytes parameter and rollover if needed.
-        """
-        try:
-            super().doRollover()
-        except OSError:
-            pass
-        finally:
-            self.need_compress = True
-        if self.compress:
-            self.do_compress_async()
-
-    def getFilesToDelete(self):
-        # always return null list
-        if self.compress:
-            return []
-        else:
-            return super().getFilesToDelete()
-
-    def __del__(self):
-        if self.compress:
-            self.do_compress()
-
-
 def get_type_default(tp, default=None):
     """Get the default value for a type. {int: 0, float: 0.0, bytes: b"", str: "", list: [], tuple: (), set: set(), dict: {}}"""
     return {
@@ -833,7 +638,7 @@ def func_cmd(function: Callable, run=True, auto_default=False):
                 seen_shorten.add(short)
                 args.insert(0, f"-{short}")
                 break
-        kwargs = dict(dest=key, help=str(value))
+        kwargs: dict = dict(dest=key, help=str(value))
         if value["type"] in {int, float, str}:
             kwargs["type"] = value["type"]
         else:
@@ -871,241 +676,12 @@ def file_import(file_path, names):
     """
     module_name = os.path.splitext(os.path.basename(file_path))[0]
     spec = importlib.util.spec_from_file_location(module_name, file_path)
-    module = importlib.util.module_from_spec(spec)
-    spec.loader.exec_module(module)
-    return {name: getattr(module, name) for name in names}
-
-
-class RotatingFileWriter:
-    """RotatingFileWriter class for writing to a file with rotation support.
-
-    Demo::
-
-        >>> # test normal usage
-        >>> writer = RotatingFileWriter("test.log", max_size=10 * 1024, max_backups=1)
-        >>> writer.write("1" * 10)
-        >>> writer.path.stat().st_size
-        0
-        >>> writer.flush()
-        >>> writer.path.stat().st_size
-        10
-        >>> writer.clean_backups(writer.max_backups)
-        >>> writer.unlink_file()
-        >>> # test rotating
-        >>> writer = RotatingFileWriter("test.log", max_size=20, max_backups=2)
-        >>> writer.write("1" * 15)
-        >>> writer.write("1" * 15)
-        >>> writer.write("1" * 15, flush=True)
-        >>> writer.path.stat().st_size
-        15
-        >>> len(writer.backup_path_list())
-        2
-        >>> writer.clean_backups(writer.max_backups)
-        >>> writer.unlink_file()
-        >>> # test no backups
-        >>> writer = RotatingFileWriter("test.log", max_size=20, max_backups=0)
-        >>> writer.write("1" * 15)
-        >>> writer.write("1" * 15)
-        >>> writer.write("1" * 15, flush=True)
-        >>> writer.path.stat().st_size
-        15
-        >>> len(writer.backup_path_list())
-        0
-        >>> writer.clean_backups(writer.max_backups)
-        >>> len(writer.backup_path_list())
-        0
-        >>> writer = RotatingFileWriter("test.log", max_size=20, max_backups=3)
-        >>> writer.print("1" * 100)
-        >>> writer.unlink(rotate=False)
-        >>> len(writer.backup_path_list())
-        1
-        >>> writer.unlink(rotate=True)
-        >>> len(writer.backup_path_list())
-        0
-        >>> writer = RotatingFileWriter("test.log", max_size=20, max_backups=3, compress=True)
-        >>> writer.print("1" * 100)
-        >>> len(writer.backup_path_list())
-        1
-        >>> writer.unlink(rotate=True)
-        >>> len(writer.backup_path_list())
-        0
-    """
-
-    check_exist_every = 100
-
-    def __init__(
-        self,
-        path: Union[Path, str],
-        max_size=5 * 1024**2,
-        max_backups=0,
-        encoding="utf-8",
-        errors=None,
-        buffering=-1,
-        newline=None,
-        compress=False,
-    ):
-        if max_backups < 0:
-            raise ValueError("max_backups must be greater than -1, 0 for itself.")
-        self._compress_threads: WeakSet = WeakSet()
-        self._rotate_lock = RLock()
-        self.path = Path(path)
-        self.path.parent.mkdir(parents=True, exist_ok=True)
-        self.max_size = max_size
-        self.max_backups = max_backups
-        self.encoding = encoding
-        self.errors = errors
-        self.buffering = buffering
-        self.newline = newline
-        self.compress = compress
-        self.file = self.reopen_file()
-        self._check_exist_count = self.check_exist_every + 1
-
-    def get_suffix(self):
-        return time.strftime("%Y%m%d%H%M%S")
-
-    def unlink_file(self):
-        return self.unlink(rotate=False)
-
-    def unlink(self, rotate=True, parent=False):
-        self.close_file()
-        self.path.unlink(missing_ok=True)
-        if rotate:
-            self.clean_backups(count=self.max_backups + 1)
-        if parent:
-            for _ in self.path.parent.iterdir():
-                return
-            else:
-                self.path.parent.rmdir()
-
-    def close(self):
-        return self.close_file()
-
-    def __enter__(self):
-        return self
-
-    def __exit__(self, *_):
-        self.shutdown()
-
-    def shutdown(self):
-        self.close_file()
-        if self.compress:
-            for t in self._compress_threads:
-                t.join()
-
-    def close_file(self):
-        file_obj = getattr(self, "file", None)
-        if file_obj and not file_obj.closed:
-            file_obj.close()
-            self.file = None
-
-    def reopen_file(self):
-        self.close_file()
-        self.file = self.path.open(
-            "a",
-            encoding=self.encoding,
-            errors=self.errors,
-            buffering=self.buffering,
-            newline=self.newline,
-        )
-        return self.file
-
-    def check_exist(self):
-        return not (
-            self._check_exist_count > self.check_exist_every and not self.path.is_file()
-        )
-
-    def rotate(self, new_length):
-        with self._rotate_lock:
-            if self.need_rotate(new_length):
-                if self.max_backups > 0:
-                    self.close_file()
-                    _suffix = self.get_suffix()
-                    for index in range(self.max_backups):
-                        if index:
-                            suffix = f"{_suffix}_{index}"
-                        else:
-                            suffix = _suffix
-                        target_path = self.path.with_name(f"{self.path.name}.{suffix}")
-                        if target_path.is_file():
-                            # already rotated
-                            continue
-                        else:
-                            break
-                    else:
-                        raise RuntimeError(
-                            "max_backups is too small for writing too fast"
-                        )
-                    self.path.rename(target_path)
-                    self.reopen_file()
-                    if not self.compress:
-                        self.clean_backups(count=None)
-                else:
-                    self.file.seek(0)
-                    self.file.truncate()
-
-    def do_compress(self):
-        with self._rotate_lock:
-            for path in self.path.parent.glob(f"{self.path.name}.*"):
-                if path.name == self.path.name:
-                    continue
-                elif path.suffix == ".gz":
-                    continue
-                temp_path = path.with_name(path.name + ".gz")
-                with GzipFile(temp_path, "wb") as gzip_file:
-                    with path.open("rb") as src_file:
-                        for line in src_file:
-                            gzip_file.write(line)
-                path.unlink(missing_ok=True)
-            self.clean_backups()
-
-    def need_rotate(self, new_length):
-        return self.max_size and self.file.tell() + new_length > self.max_size
-
-    def ensure_file(self, new_length=0):
-        if not self.file:
-            self.reopen_file()
-        elif not self.check_exist():
-            self.reopen_file()
-        elif self.need_rotate(new_length):
-            self.rotate(new_length)
-            if self.compress:
-                t = Thread(target=self.do_compress)
-                t.start()
-                self._compress_threads.add(t)
-
-    def backup_path_list(self):
-        return list(self.path.parent.glob(f"{self.path.name}.*"))
-
-    def clean_backups(self, count=None):
-        """Clean oldest {count} backups, if count is None, it will clean up to max_backups."""
-        with self._rotate_lock:
-            path_list = self.backup_path_list()
-            if path_list:
-                if count is None:
-                    count = len(path_list) - self.max_backups
-                if count > 0:
-                    path_list.sort(key=lambda x: x.stat().st_mtime)
-                    for deleted, path in enumerate(path_list, 1):
-                        path.unlink(missing_ok=True)
-                        if deleted >= count:
-                            break
-
-    def flush(self):
-        self.file.flush()
-
-    def write(self, text: str, flush=False):
-        self._check_exist_count += 1
-        self.ensure_file(len(text))
-        self.file.write(text)
-        if flush:
-            self.file.flush()
-
-    def print(self, *strings, end="\n", sep=" ", flush=False):
-        text = f"{sep.join(map(str, strings))}{end}"
-        self.write(text, flush=flush)
-
-    def __del__(self):
-        self.shutdown()
+    if spec and spec.loader:
+        module = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(module)
+        return {name: getattr(module, name) for name in names}
+    else:
+        return {}
 
 
 def get_function(entrypoint: str):
@@ -1126,89 +702,6 @@ async def to_thread(func, /, *args, **kwargs):
     return await asyncio.get_running_loop().run_in_executor(None, func_call)
 
 
-class AsyncQueueListener(QueueListener):
-    """Asynchronous non-blocking QueueListener that manages logger handlers.
-    logger is a logging.Logger instance.
-    queue is a Queue or ProcessQueue instance.
-    respect_handler_level is a boolean that determines if the handler level should be respected.
-
-    Example:
-
-        async def main():
-            # Create logger with a blocking handler
-            logger = logging.getLogger("example")
-            logger.setLevel(logging.INFO)
-            stream_handler = logging.StreamHandler()
-            stream_handler.setFormatter(
-                logging.Formatter("%(asctime)s - %(levelname)s - %(message)s")
-            )
-            logger.addHandler(stream_handler)
-            # Use async queue listener
-            async with AsyncQueueListener(logger):
-                # Log won't block the event loop
-                for i in range(5):
-                    logger.info("log info")
-                    logger.debug("log debug")
-                    await asyncio.sleep(0.01)
-    """
-
-    def __init__(
-        self,
-        logger: logging.Logger,
-        queue: Optional[Union[Queue, ProcessQueue]] = None,
-        respect_handler_level=True,
-    ):
-        self.logger = logger
-        self.queue = queue or Queue()
-        # Store original handlers
-        self.original_handlers = list(logger.handlers)
-        # Get handlers that might block
-        self.blocking_handlers = [
-            h for h in self.original_handlers if not isinstance(h, QueueHandler)
-        ]
-        # Initialize parent with queue and blocking handlers
-        super().__init__(
-            self.queue,
-            *self.blocking_handlers,
-            respect_handler_level=respect_handler_level,
-        )
-
-    def _switch_to_queue_handler(self):
-        """Switch handlers in a blocking context"""
-        # Remove original handlers
-        for handler in self.original_handlers:
-            self.logger.removeHandler(handler)
-        # Add queue handler
-        self.logger.addHandler(QueueHandler(self.queue))
-
-    def _restore_original_handlers(self):
-        """Restore original handlers in a blocking context"""
-        # Remove queue handler
-        self.logger.removeHandler(self.logger.handlers[0])
-        # Restore original handlers
-        for handler in self.original_handlers:
-            self.logger.addHandler(handler)
-
-    def stop(self):
-        super().stop()
-        self._restore_original_handlers()
-
-    def start(self):
-        self._switch_to_queue_handler()
-        super().start()
-
-    async def __aenter__(self):
-        await to_thread(self.start)
-        return self
-
-    async def __aexit__(self, exc_type, exc_val, exc_tb):
-        await to_thread(self.stop)
-
-
-# alias for AsyncQueueListener
-async_logger = AsyncQueueListener
-
-
 def check_recursion(function: Callable, return_error=False):
     """Check if a function is recursive by inspecting its AST.
     Returns True if the function calls itself, otherwise False.
@@ -1246,21 +739,44 @@ def check_recursion(function: Callable, return_error=False):
             return None
 
 
+class LineTime(object):
+    __slots__ = ("line_no", "start_time", "end_time", "code")
+
+    def __init__(
+        self, line_no: int, start_time: float, end_time: Optional[float], code: str
+    ):
+        self.line_no = line_no
+        self.start_time = start_time
+        self.end_time = end_time
+        self.code = code
+
+
 class LineProfiler:
     """Line-by-line performance profiler."""
 
     stdout = sys.stdout
 
-    def __init__(self):
-        self.line_times: List[Tuple[int, float, str]] = []
+    def __init__(self) -> None:
+        self.line_times: List[LineTime] = []
         self.start_time = 0.0
         self.total_time = 0.0
         self.line_cache: Dict[str, list] = {}
+        self.filled = 0
 
     def trace_calls(self, frame, event, arg):
         """Trace each line of function calls"""
+        current_time = time.perf_counter()
+        if self.filled < len(self.line_times):
+            self.filled += 1
+            last_item = self.line_times[-1]
+            if last_item.end_time is None:
+                self.line_times[-1] = LineTime(
+                    last_item.line_no,
+                    last_item.start_time,
+                    current_time,
+                    last_item.code,
+                )
         if event == "line":
-            current_time = time.perf_counter()
             line_no = frame.f_lineno
             filename = frame.f_code.co_filename
             # Get the code content of current line
@@ -1284,7 +800,7 @@ class LineProfiler:
             except Exception:
                 line_content = "-"
                 self.line_cache.setdefault(filename, [])
-            self.line_times.append((line_no, current_time, line_content))
+            self.line_times.append(LineTime(line_no, current_time, None, line_content))
         return self.trace_calls
 
     def _get_function_base_indent(self, func_name: str):
@@ -1304,23 +820,23 @@ class LineProfiler:
             return
         # Calculate base indentation level of function
         base_indent = self._get_function_base_indent(func_name)
+        print(f"{'=' * 95}", file=self.stdout)
         print(f"`{func_name}` profiling report:", file=self.stdout)
         start_time = time.strftime("%Y-%m-%d %H:%M:%S")
         print(
-            f"{start_time} | Total: {self.total_time * 1000:.3f} ms",
+            f"Start at {start_time} | Total: {self.total_time * 1000:.3f} ms",
             file=self.stdout,
         )
         # Calculate execution time for each line
         line_durations = []
-        for i in range(1, len(self.line_times)):
-            prev_time = self.line_times[i - 1][1]
-            curr_time = self.line_times[i][1]
-            duration = curr_time - prev_time
+        for item in self.line_times:
+            if item.end_time is None:
+                continue
             line_durations.append(
                 (
-                    self.line_times[i - 1][0],  # line number
-                    duration,  # duration
-                    self.line_times[i - 1][2],  # code content
+                    item.line_no,  # line number
+                    item.end_time - item.start_time,  # duration
+                    item.code,  # code content
                 )
             )
         # Sort by line number and merge time for same lines
@@ -1389,19 +905,20 @@ def line_profiler(func: Callable) -> Callable:
         >>> example_function()
         45
         >>> output = LineProfiler.stdout.getvalue()
-        >>> output.splitlines()[0].startswith("`example_function` profiling report:")
+        >>> output.splitlines()[0].startswith("=" * 95) and "`example_function` profiling report:" in output
         True
         >>> LineProfiler.stdout = sys.stdout  # Restore original stdout
 
-    # `example_function` profiling report:
-    # 2025-07-26 17:09:58 | Total: 1.122 ms
-    # ===============================================================================================
-    #   Line    %    Total(ms)    Count      Avg(ms)  Source Code
-    # -----------------------------------------------------------------------------------------------
-    #      3   73        0.825        1        0.825  -
-    #      4    3        0.040       11        0.004  -
-    #      5    4        0.050       10        0.005  -
-    # ===============================================================================================
+===============================================================================================
+`example_function` profiling report:
+Start at 2025-07-26 17:09:58 | Total: 1.122 ms
+===============================================================================================
+  Line    %    Total(ms)    Count      Avg(ms)  Source Code
+-----------------------------------------------------------------------------------------------
+     3   73        0.825        1        0.825  -
+     4    3        0.040       11        0.004  -
+     5    4        0.050       10        0.005  -
+===============================================================================================
     """
 
     @wraps(func)
@@ -1457,7 +974,7 @@ def test_named_lock():
             tasks = [pool.submit(_test1) for _ in range(3)]
             result = [i.result() for i in tasks]
             assert result == [True, False, False], result
-        assert len(NamedLock._SYNC_CACHE) == 1
+        assert len(NamedLock._SYNC_CACHE) == 1, NamedLock._SYNC_CACHE
         NamedLock.clear_unlocked()
         assert len(NamedLock._SYNC_CACHE) == 0
 
@@ -1504,38 +1021,13 @@ def test_named_lock():
     test_async()
 
 
-def test_AsyncQueueListener():
-    """Test AsyncQueueListener logs without blocking"""
-
-    async def _test():
-        from io import StringIO
-
-        mock_stdout = StringIO()
-        # Create logger with a blocking handler
-        logger = logging.getLogger("example")
-        logger.setLevel(logging.INFO)
-        stream_handler = logging.StreamHandler(stream=mock_stdout)
-        stream_handler.setFormatter(
-            logging.Formatter("%(asctime)s - %(levelname)s - %(message)s")
-        )
-        logger.addHandler(stream_handler)
-        # Use async queue listener
-        async with AsyncQueueListener(logger):
-            # Log won't block the event loop
-            for i in range(5):
-                logger.info("log info")
-                logger.debug("log debug")
-        text = mock_stdout.getvalue()
-        assert text.count("log info") == 5
-        assert text.count("log debug") == 0
-
-    asyncio.run(_test()) is True
-
-
 def test_utils():
     test_bg_task()
+    print(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()), "test_bg_task passed")
     test_named_lock()
-    test_AsyncQueueListener()
+    print(
+        time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()), "test_named_lock passed"
+    )
 
 
 def test():
