@@ -174,7 +174,7 @@ class SocketServer:
     def __init__(
         self,
         host: str = "127.0.0.1",
-        port: int = 8090,
+        port: Optional[int] = 8090,
         handler: Optional[Callable] = None,
         encoder: Optional[IPCEncoder] = None,
         connect_kwargs: Optional[dict] = None,
@@ -239,10 +239,17 @@ class SocketServer:
             await writer.wait_closed()
 
     async def close(self):
-        if self.is_serving():
+        if self.server and self.is_serving():
+            if self._shutdown_ev:
+                self._shutdown_ev.set()
             self.server.close()
+            if hasattr(self.server, "close_clients"):
+                # 3.13+
+                self.server.close_clients()
+                self.server.abort_clients()
+            else:
+                pass
             await self.server.wait_closed()
-            self._shutdown_ev.set()
             if self.end_callback:
                 if asyncio.iscoroutinefunction(self.end_callback):
                     await self.end_callback()
@@ -262,9 +269,13 @@ class SocketServer:
             )
             await self.server.start_serving()
         else:
-            self.server = await asyncio.start_unix_server(
-                self.connect_callback, path=self.host, **self.connect_kwargs
-            )
+            start_unix_server = getattr(asyncio, "start_unix_server", None)
+            if start_unix_server:
+                self.server = await start_unix_server(
+                    self.connect_callback, path=self.host, **self.connect_kwargs
+                )
+            else:
+                raise RuntimeError("asyncio.start_unix_server is not available")
         if self.start_callback:
             if asyncio.iscoroutinefunction(self.start_callback):
                 await self.start_callback()
@@ -282,8 +293,13 @@ class SocketServer:
 
     def shutdown(self):
         "sync close"
-        if self.is_serving():
-            self.server.get_loop().call_soon_threadsafe(self._shutdown_ev.set)
+        if self.server and self.is_serving():
+            self.server.get_loop().call_soon_threadsafe(
+                lambda: [
+                    self._shutdown_ev.set() if self._shutdown_ev else None,
+                    self.server.close() if self.server else None,
+                ]
+            )
 
     async def __aenter__(self):
         await self.start()
@@ -297,7 +313,7 @@ class SocketClient:
     def __init__(
         self,
         host: str = "127.0.0.1",
-        port: int = 8090,
+        port: Optional[int] = 8090,
         encoder: Optional[IPCEncoder] = None,
         connect_kwargs: Optional[dict] = None,
     ):
@@ -312,7 +328,10 @@ class SocketClient:
                 self.host, self.port, **self.connect_kwargs
             )
         else:
-            self.reader, self.writer = await asyncio.open_unix_connection(
+            open_unix_connection = getattr(asyncio, "open_unix_connection", None)
+            if not open_unix_connection:
+                raise RuntimeError("asyncio.open_unix_connection is not available")
+            self.reader, self.writer = await open_unix_connection(
                 path=self.host, **self.connect_kwargs
             )
         self.lock = asyncio.Lock()
@@ -392,7 +411,11 @@ def is_port_free(
             return True
 
 
-async def test_client(host="127.0.0.1", port=8090, encoder=None, cases=None):
+async def test_client(
+    host="127.0.0.1", port: Optional[int] = 8090, encoder=None, cases=None
+):
+    if cases is None:
+        raise ValueError("cases is None")
     async with SocketClient(host=host, port=port, encoder=encoder) as c:
         for case in cases:
             await c.send(case)
@@ -447,6 +470,8 @@ async def _test_ipc_logging():
 
         # ensure test case
         await asyncio.sleep(0.1)
+        if not h.sock:
+            raise RuntimeError("socket is None")
         assert pickle.loads(h.sock.recv(100000)[4:])["name"] == logger.name
         h.sock.close()
 
