@@ -1064,6 +1064,7 @@ def xor_encode_decode(data, key):
 def is_running_win32(pid: int):
     with os.popen('tasklist /fo csv /fi "pid eq %s"' % int(pid)) as f:
         f.readline()
+        # the second line is the result
         text = f.readline()
         return bool(text)
 
@@ -1090,7 +1091,9 @@ def is_running(pid):
     Examples:
     >>> is_running(os.getpid() * 10)  # Assume process is not running
     False
-    >>> is_running(os.getpid())  # Check if the current process is running
+    >>> current_pid = os.getpid()
+    >>> # sometimes may return False on Windows due to permission issues!
+    >>> is_running(current_pid) or is_running(current_pid)  # Check if the current process is running
     True
     >>> is_running("not_a_pid")  # Invalid PID input should be handled and return False
     False
@@ -1504,7 +1507,9 @@ class FileDict(dict):
             pass
 
 
-def i2b(n: int, length=0, byteorder="big", signed=False) -> bytes:
+def i2b(
+    n: int, length=0, byteorder: Literal["litter", "big"] = "big", signed=False
+) -> bytes:
     r"""Convert an int to bytes of a specified length, commonly used in TCP communication.
 
     Parameters:
@@ -1704,11 +1709,17 @@ class PathLock:
             self.lock.acquire(blocking=True)
 
     def __exit__(self, *_):
-        with self.GLOBAL_LOCK:
-            try:
-                self.LOCKS.remove(self.path)
-            except ValueError:
-                pass
+        try:
+            if self.GLOBAL_LOCK:
+                locked = self.GLOBAL_LOCK.acquire(blocking=True)
+            else:
+                locked = False
+            self.LOCKS.remove((self.path, self.lock))
+        except ValueError:
+            pass
+        finally:
+            if self.GLOBAL_LOCK and locked:
+                self.GLOBAL_LOCK.release()
         self.lock.release()
 
     async def __aenter__(self):
@@ -1716,11 +1727,17 @@ class PathLock:
         await self.lock.acquire()
 
     async def __aexit__(self, *_):
-        with self.GLOBAL_LOCK:
-            try:
-                self.ALOCKS.remove(self.path)
-            except ValueError:
-                pass
+        try:
+            if self.GLOBAL_ALOCK:
+                locked = await self.GLOBAL_ALOCK.acquire()
+            else:
+                locked = False
+            self.ALOCKS.remove((self.path, self.lock))
+        except ValueError:
+            pass
+        finally:
+            if self.GLOBAL_ALOCK and locked:
+                self.GLOBAL_ALOCK.release()
         self.lock.release()
 
 
@@ -1847,7 +1864,11 @@ def base_decode(
 
 
 def gen_id(rand_len=4) -> str:
-    """Generate a unique ID based on the current time and random bytes
+    """Generate a unique ID based on the current time and random bytes.
+
+    If rand_len=0 the length of ID will be 18, rand_len=4 the length of ID will be 22.
+    ID format:
+    - {YYMMDD_HHMMSS}_{4-digit base62 of microsecond}{rand_len urandom hex string}
 
     Args:
         rand_len (int, optional): Defaults to 4.
@@ -1863,12 +1884,17 @@ def gen_id(rand_len=4) -> str:
     >>> ids = [time.sleep(0.000001) or gen_id() for _ in range(1000)]
     >>> len(set(ids))
     1000
+    >>> [len(gen_id(i)[:]) for i in range(10)]
+    [18, 19, 20, 21, 22, 23, 24, 25, 26, 27]
     """
     now = datetime.now()
     s1 = now.strftime("%y%m%d_%H%M%S")
     s2 = base_encode(now.microsecond)
-    s2 = f"{s2:>04}{os.urandom(rand_len // 2).hex()}"
-    return f"{s1}_{s2}"
+    if rand_len:
+        s3 = os.urandom(rand_len // 2 + 1).hex()[:rand_len]
+    else:
+        s3 = ""
+    return f"{s1}_{s2:>04}{s3}"
 
 
 def timeti(
@@ -1917,7 +1943,7 @@ class SnowFlake:
         seq_bit=12,  # between 0 and 4095
         start_date="2025-01-01",
     ):
-        r"""Generate unique IDs using Twitter's Snowflake algorithm.
+        r"""Generate unique IDs using Twitter's Snowflake algorithm. The Snowflake algorithm is an efficient, distributed, globally unique, and ordered ID generation algorithm suitable for large-scale distributed systems.
 
         The ID is composed of:
         - 41 bits timestamp in milliseconds since a custom epoch
